/***************************************************************************
    Kpass - Internet Password Passwortmanager
    ------------------------------------------------------------------------
    begin              : 21-2-2001
    version            : 0.012 1st release
    copyright          : (C) 2001 by Karl E. Maij
    email              : kem@sitedesign.ch
    website            : http://www.sitedesign.ch
    doc                : http://www.maij.ch/downloads/docs/kpass/

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation.	See http://www.gnu.org		
****************************************************************************/

#include "kpopt.h"
#include "kpopt.moc"
#include "kppics.h"


// global config data defined in kpass
extern int pwdGeneratorValue;
extern bool isPasswdChecked;
extern bool isInfoMsgChecked;
extern bool isShowTipChecked;
extern bool isEncryptChecked;
extern bool isEditMaskChecked;
extern bool isBrowserChecked;
extern bool isBrowserLogin;
extern bool isFtpLogin;
extern QString whatPassword;
extern QString progBrowserName;
extern QString progFtpName;
extern QString filePath;


Kpopt::Kpopt( QWidget *parent,  const char *name, WFlags fl ) : KDialog( parent, name, true, fl ){

  QPixmap image0( ( const char** ) image0_data );
  if ( !name )
  setName( "Kpopt" );
  this->setFixedSize( 397, 340 );
  setCaption( i18n( "Global Options" ) );
  setIcon( image0 );

  // Configure Box
  ConfigBox = new QGroupBox( this, "ConfigBox" );

  ConfigBox->setGeometry( QRect( 6, 6, 190, 80 ) );
  ConfigBox->setFrameShadow( QGroupBox::Plain );
  ConfigBox->setFrameShape( QGroupBox::Box );

  cbMessages = new QCheckBox( ConfigBox, "cbMessages" );
  cbMessages->setGeometry( QRect( 8, 7, 180, 20 ) );
  cbMessages->setText( i18n( "Show infomessages" ) );
  cbMessages->setChecked( isInfoMsgChecked );

  cbTooltipps = new QCheckBox( ConfigBox, "cbTooltipps" );
  cbTooltipps->setGeometry( QRect( 8, 31, 180, 20 ) );
  cbTooltipps->setText( i18n( "Show tooltipps" ) );
  cbTooltipps->setChecked( isShowTipChecked );

	// encryption not implemented yet
  cbKrypt = new QCheckBox( ConfigBox, "cbKrypt" );
  cbKrypt->setGeometry( QRect( 8, 56, 180, 16 ) );
  cbKrypt->setText( i18n( "Encrypt data when quit" ) );
  cbKrypt->setChecked( isEncryptChecked );
	cbKrypt->setEnabled(false);

  // Generator Box
  GeneratorBox = new QGroupBox( this, "GeneratorBox" );
  GeneratorBox->setGeometry( QRect( 200, 6, 190, 80 ) );
  GeneratorBox->setFrameShadow( QGroupBox::Plain );

  txtTick = new QLabel( GeneratorBox, "txtTick" );
  txtTick->setGeometry( QRect( 89, 52, 16, 16 ) );
  txtTick->setNum( pwdGeneratorValue );

  lblUnsecure = new QLabel( GeneratorBox, "lblUnsecure" );
  lblUnsecure->setGeometry( QRect( 8, 52, 75, 20 ) );
  lblUnsecure->setText( i18n( "Unsecure" ) );

  lblSecure = new QLabel( GeneratorBox, "lblSecure" );
  lblSecure->setGeometry( QRect( 115, 54, 65, 16 ) );
  lblSecure->setText( i18n( "Secure" ) );
  lblSecure->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

  lblPasswordGenerator = new QLabel( GeneratorBox, "lblPasswortgenerator" );
  lblPasswordGenerator->setGeometry( QRect( 8, 6, 180, 21 ) );
  lblPasswordGenerator->setText( i18n( "Password generator (global)" ) );

  slGenerator = new QSlider( GeneratorBox, "slGenerator" );
  slGenerator->setGeometry( QRect( 10, 27, 170, 21 ) );
  slGenerator->setOrientation( QSlider::Horizontal );
  slGenerator->setTickInterval( 1 );
  slGenerator->setMinValue( 1 );
  slGenerator->setMaxValue( 16 );
  slGenerator->setValue( pwdGeneratorValue );
  slGenerator->setTickmarks( QSlider::Right );
  slGenerator->setAutoMask( FALSE );
	slGenerator->setTracking( true );
	if(isShowTipChecked){
		QToolTip::add( slGenerator, i18n( " Select size of generated passwords " ) );
  }

  // Box for Edit config
  EditBox = new QButtonGroup( this, "EditBox" );
  EditBox->setGeometry( QRect( 6, 91, 190, 70 ) );
  EditBox->setTitle( i18n( "" ) );
  EditBox->setFrameShadow( QGroupBox::Plain );
  EditBox->setFrameShape( QGroupBox::Box );

  lblListDoubleClick = new QLabel( EditBox, "lblListDoubleClick" );
  lblListDoubleClick->setGeometry( QRect( 7, 5, 180, 20 ) );
  lblListDoubleClick->setText( i18n( "Doubleclick in listbox opens:" ) );

  rbMask = new QRadioButton( EditBox, "rbMask" );
  rbMask->setGeometry( QRect( 7, 22, 180, 21 ) );
  rbMask->setText( i18n( "Edit password mask" ) );
  rbMask->setChecked( isEditMaskChecked );

  rbBrowser = new QRadioButton( EditBox, "rbBrowser" );
  rbBrowser->setGeometry( QRect( 7, 43, 180, 21 ) );
  rbBrowser->setText( i18n( "Browser with Url" ) );
  rbBrowser->setChecked( isBrowserChecked );

  //Programm Password Box
  PasswordBox = new QGroupBox( this, "PasswordBox" );
  PasswordBox->setGeometry( QRect( 200, 91, 190, 70 ) );
  PasswordBox->setTitle( i18n( "" ) );
  PasswordBox->setFrameShadow( QGroupBox::Plain );

  cbPasswordSecurity = new QCheckBox( PasswordBox, "cbPasswordSecurity" );
  cbPasswordSecurity->setGeometry( QRect( 8, 4, 170, 21 ) );
  cbPasswordSecurity->setText( i18n( "Application password" ) );
  cbPasswordSecurity->setChecked( isPasswdChecked );

  txtPassword = new QLineEdit( PasswordBox, "txtPassword" );
  txtPassword->setGeometry( QRect( 8, 40, 145, 22 ) );
  txtPassword->setEnabled( isPasswdChecked );
  txtPassword->setText( whatPassword );

  lblPassword = new QLabel( PasswordBox, "lblPassword" );
  lblPassword->setGeometry( QRect( 8, 23, 60, 16 ) );
  lblPassword->setText( i18n( "Password" ) );

  cmdGenerator = new QPushButton( PasswordBox, "cmdGenerator" );
  cmdGenerator->setGeometry( QRect( 160, 40, 22, 22 ) );
  cmdGenerator->setPixmap( image0 );
  cmdGenerator->setEnabled( isPasswdChecked );
	if(isShowTipChecked){
  	QToolTip::add(  cmdGenerator, i18n( "Generate password" ) );
  }

  // Box for Applications
  AppBox = new QGroupBox( this, "AppBox" );
  AppBox->setGeometry( QRect( 5, 165, 385, 125 ) );
  AppBox->setFrameShadow( QGroupBox::Plain );

  txtBrowser = new QLineEdit( AppBox, "txtBrowser" );
  txtBrowser->setGeometry( QRect( 7, 25, 265, 22 ) );
  txtBrowser->setText( progBrowserName );

  txtFtp = new QLineEdit( AppBox, "txtFtp" );
  txtFtp->setGeometry( QRect( 7, 70, 265, 22 ) );
  txtFtp->setText( progFtpName );

  lblPathBrowser = new QLabel( AppBox, "lblPathBrowser" );
  lblPathBrowser->setGeometry( QRect( 8, 5, 241, 21 ) );
  lblPathBrowser->setText( i18n( "Path to browser or program name" ) );

  lblPathFtp = new QLabel( AppBox, "lblPathFtp" );
  lblPathFtp->setGeometry( QRect( 8, 53, 196, 16 ) );
  lblPathFtp->setText( i18n( "Path to FTP or program name" ) );

  cmdFtp = new QPushButton( AppBox, "cmdFtp" );
  cmdFtp->setGeometry( QRect( 278, 70, 101, 22 ) );
  cmdFtp->setText( i18n( "Search" ) );
  cmdFtp->setAutoMask( true );
	if(isShowTipChecked){
	QToolTip::add( cmdFtp, i18n( "Select path or name of your browser" ) );
  }

  cbBrowserLogin = new QCheckBox( AppBox, "cbBrowserLogin" );
  cbBrowserLogin->setGeometry( QRect( 8, 97, 180, 21 ) );
  cbBrowserLogin->setChecked( isBrowserLogin );
  cbBrowserLogin->setText( i18n( "Automatical browser login" ) );

  cbFtpLogin = new QCheckBox( AppBox, "cbFtpLogin" );
  cbFtpLogin->setGeometry( QRect( 205, 97, 160, 21 ) );
  cbFtpLogin->setChecked( isFtpLogin );
  cbFtpLogin->setText( i18n( "Automatical ftp login" ) );

  cmdBrowser = new QPushButton( AppBox, "cmdBrowser" );
  cmdBrowser->setGeometry( QRect( 278, 25, 101, 22 ) );
  cmdBrowser->setText( i18n( "Search" ) );
  cmdBrowser->setAutoMask( true );
	if(isShowTipChecked){
		QToolTip::add( cmdBrowser, i18n( "Select path or name of your ftp program" ) );
  }

  // General Button Box
  ButtonBox = new QGroupBox( this, "ButtonBox" );
  ButtonBox->setGeometry( QRect( 5, 295, 385, 35 ) );
  ButtonBox->setTitle( i18n( "" ) );
  ButtonBox->setFrameShadow( QGroupBox::Plain );

  cmdCancel = new QPushButton( ButtonBox, "cmdCancel" );
  cmdCancel->setGeometry( QRect( 135, 7, 120, 22 ) );
  cmdCancel->setText( i18n( "Cancel" ) );
  cmdCancel->setAutoMask( true );

  cmdStandard = new QPushButton( ButtonBox, "cmdStandard" );
  cmdStandard->setGeometry( QRect( 5, 7, 125, 22 ) );
  cmdStandard->setText( i18n( "Standard" ) );
  cmdStandard->setAutoMask( true );
	if(isShowTipChecked){
		QToolTip::add( cmdStandard, i18n( " Set all options to Standard " ) );
  }

  cmdSave = new QPushButton( ButtonBox, "cmdSave" );
  //connect( cmdOk, SIGNAL( clicked() ), this, SLOT( accept() ) );
  cmdSave->setGeometry( QRect( 260, 7, 120, 22 ) );
  cmdSave->setText( i18n( "Save" ) );
  cmdSave->setAutoMask( true );
	if(isShowTipChecked){
		QToolTip::add( cmdSave, i18n( " Save changes you made " ) );
  }

  // tab order
  setTabOrder( cbMessages, cbTooltipps );
  setTabOrder( cbTooltipps, cbKrypt );
  setTabOrder( cbKrypt, slGenerator );
  setTabOrder( slGenerator, rbMask );
  setTabOrder( rbMask, rbBrowser );
  setTabOrder( rbBrowser, cbPasswordSecurity );
  setTabOrder( cbPasswordSecurity, txtPassword );
  setTabOrder( txtPassword, txtBrowser );
  setTabOrder( txtBrowser, cmdBrowser );
  setTabOrder( cmdBrowser, txtFtp );
  setTabOrder( txtFtp, cmdFtp );
  setTabOrder( cmdFtp, cmdStandard );
  setTabOrder( cmdStandard, cmdCancel );
  setTabOrder( cmdCancel, cmdSave );

  //Signals
  connect( slGenerator, SIGNAL( valueChanged(int) ), txtTick, SLOT( setNum(int) ) );
  connect( cbPasswordSecurity, SIGNAL( toggled(bool) ), txtPassword, SLOT( setEnabled(bool) ) );
  connect( cbPasswordSecurity, SIGNAL( toggled(bool) ), cmdGenerator, SLOT( setEnabled(bool) ) );
  connect( cmdCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
  connect( cmdSave, SIGNAL( clicked() ), this, SLOT( accept() ) );
  connect( cmdFtp, SIGNAL( clicked() ), this, SLOT( findAppFtp() ) );
  connect( cmdBrowser, SIGNAL( clicked() ), this, SLOT( findAppBrowser() ) );
  connect( cmdStandard, SIGNAL( clicked() ), this, SLOT( standardEntry() ) );
	connect( cmdGenerator, SIGNAL( clicked() ), this, SLOT( pwdGenerator() ) );


	// Text for 'what's tis' function - pointed on the boxes
	QWhatsThis::add(  ConfigBox, i18n(
		"Here you can say that the programm helps "
		"you with infomessages and tooltipps." ) );

	QWhatsThis::add(  EditBox, i18n(
		"A doubleclick in the group and the "
		"password list will open a edit mask."
		"Here you say the progam launches the "
		"related webprogram if you "
		"doubleclick on password list. The "
		"group list is not affected.") );

	QWhatsThis::add(  PasswordBox, i18n(
		"If you want to have a login for this "
		"program check here and choose a password. "
		"The password will be stored in "
		"your configuration data and is not "
		"secure but should give a small barrier "
		"when you forget to exit your desktop.") );

	QWhatsThis::add(  GeneratorBox, i18n(
		"Slider for global password generator.") );

	QWhatsThis::add(  AppBox, i18n(
		"Here you can change your default "
		"browser or ftp program. If the program "
		"is in your search path only the name is "
		"required e.g. 'konqueror' or 'netscape'. "
		"Leaving the checkboxes checked will allow "
		"the program to log in the server for you") );

}

// select the ftp application
void Kpopt::findAppFtp(){
  QFileDialog *saveSlutDlg = new QFileDialog(this, "saveSlutDlg");
  saveSlutDlg->setCaption("Get ftp");
  saveSlutDlg->setMode(QFileDialog::ExistingFile);
  QString fileName = saveSlutDlg->getOpenFileName("" , "*", this );
	if ( !fileName.isNull() ) {
		txtFtp->setText(fileName);
	}else{
   	QMessageBox::warning(this, i18n( "Nothing to do!" ), i18n(
						"No Ftp program selected\n using defaults.") );
	}	
}

// select the browser
void Kpopt::findAppBrowser(){
  QFileDialog *saveSlutDlg = new QFileDialog(this, "saveSlutDlg");
  saveSlutDlg->setCaption("Get browser");
  saveSlutDlg->setMode(QFileDialog::ExistingFile);
  QString fileName = saveSlutDlg->getOpenFileName("" , "*", this );
	if ( !fileName.isNull() ) {
		txtBrowser->setText(fileName);
	}else{
   	QMessageBox::warning(this, i18n( "Nothing to do!" ), i18n(
									"No browser program selected\n using defaults.") );
	}	
}

// sets the standard for options
void Kpopt::standardEntry(){
	cbMessages->setChecked(true);
	cbTooltipps->setChecked(true);
  cbKrypt->setChecked(false);
  slGenerator->setValue( 8 );
  rbMask->setChecked(true);
	rbBrowser->setChecked(false);
  cbPasswordSecurity->setChecked(false);
  txtPassword->setText( "" );
  txtBrowser->setText( "konqueror" );
	txtFtp->setText( "konqueror" );
	cbFtpLogin->setChecked(true);
	cbBrowserLogin->setChecked(true);

}

// simple password generator
void Kpopt::pwdGenerator(){

	QString string =  KApplication::randomString( slGenerator->value()+1 );
	string.remove(0,1);
	txtPassword->setText( string );	
}


Kpopt::~Kpopt(){}


